%Pre cmds
clear 
close all
clc

%Add filepath
addpath('files');

%Initialize model5
InitGunnerusMan

%Simulation time and sample time
Ts = 0.01; %sample time main simulation
Tsimulation = 2500; %main simulation

%Consequence analysis
Tsim_int = 15; %Time interval between failure mode simulation

    %FAILURE MODES
    %fm1
        fm_start = 0; %time from simulation start until fm occur
        fm_duration = 250;
        rudderLoss = 0; %rudder freeze
        powerLoss = 0;
        powerFrac = 0;
        totalLoss = 1; %Will dominate the other options?
        
    %fm2
        fm_start2 = 0; %time from simulation start until fm occur
        fm_duration2 = 45;
        rudderLoss2 = 0; %rudder freeze
        powerLoss2 = 1;
        powerFrac2 = 0.2;
        totalLoss2 = 0; %Will dominate the other options?
     
    %fm3
        fm_start3 = 0; %time from simulation start until fm occur
        fm_duration3 = 45;
        rudderLoss3 = 0; %rudder freeze
        powerLoss3 = 1;
        powerFrac3 = 0.5;
        totalLoss3 = 0; %Will dominate the other options?
        
    %fm4
        fm_start4 = 0; %time from simulation start until fm occur
        fm_duration4 = 45;
        rudderLoss4 = 1; %rudder freeze
        powerLoss4 = 0;
        powerFrac4 = 1;
        totalLoss4 = 0; %Will dominate the other options?
        
%Checklist FM
%  1) Check duration
%  2) Which fm that is active
%  3) That route and objects are corretly implemented.
%  4) That consequence analysis is functioning properly.
 

%Risk Analysis
probability = [0.05 0.15 0.38 0.25];

%Current def Markus
current.enable = 1;
current.vel = 1.5;
current.dir = (270)*(pi/180);

%Choose scenario
Scenario = 0;

switch Scenario
    case 1
        %Define waypoints, format: [[nWP1;eWP1],[nWP2;eWP2]
        wayPoints = [[200;0],[140;480],[140;950],[900;1625],[1600;1350]];
        
        %Initial values
        eta_init_main = [wayPoints(1,1) wayPoints(2,1) 0 0 0 asin((wayPoints(2,2)-wayPoints(2,1))/sqrt((wayPoints(1,2)-wayPoints(1,1))^2+(wayPoints(2,2)-wayPoints(2,1))^2))]';
        nu_init_main = [3.5 0 0 0 0 0]';
        
        %Define objects, format: [[nOB1;eOB1],[nOB2;eOB2]
        obstacles21 = [[linspace(100,100);linspace(200+400,600+400)],[linspace(100,900);linspace(600+400,1300+400)],[linspace(900,1400);linspace(1300+400,1100+400)]];
        obstacles22 = [[linspace(300,300);linspace(200+400,500+400)],[linspace(300,900);linspace(500+400,1000+400)],[linspace(900,1400);linspace(1000+400,800+400)]];

        obstacles2 = [obstacles21 , obstacles22];
        obstacles1 = [[230;100]]; %obstacles
        obstacles = [obstacles1,obstacles2];
        obstLevels = [50 25 5];
        noObst = size(obstLevels,2);
        printPath = '/Users/markusfossdal/Dropbox/SKOLE/8_SKOLE_V2018/MASTER/latex/fig/sc4';
    case 2
        
        %Define waypoints, format: [[nWP1;eWP1],[nWP2;eWP2]
        wayPoints = [[0;0],[100;100],[1000;100],[1200;-300]];
        
        %Initial values
        eta_init_main = [0 0 0 0 0 asin((wayPoints(2,2)-wayPoints(2,1))/sqrt((wayPoints(1,2)-wayPoints(1,1))^2+(wayPoints(2,2)-wayPoints(2,1))^2))]';
        nu_init_main = [3.5 0 0 0 0 0]';
        
        %Define objects, format: [[nOB1;eOB1],[nOB2;eOB2]
        obstacles1 = [[400;100+25+50],[800;100+25+50],[600;-100+25+50],[1150;100]]; %obstacles
        obstacles = [obstacles1];
        obstLevels = [50 25 5];
        noObst = size(obstLevels,2);
        printPath = '/Users/markusfossdal/Dropbox/SKOLE/8_SKOLE_V2018/MASTER/latex/fig/sc2';
        
    otherwise
        %Define waypoints, format: [[nWP1;eWP1],[nWP2;eWP2]
        wayPoints = [[0;0],[150;0],[500;0]];
        
        %Initial values
        eta_init_main = [0 0 0 0 0 asin((wayPoints(2,2)-wayPoints(2,1))/sqrt((wayPoints(1,2)-wayPoints(1,1))^2+(wayPoints(2,2)-wayPoints(2,1))^2))]';
        nu_init_main = [3.5 0 0 0 0 0]';
        
        %Define objects, format: [[nOB1;eOB1],[nOB2;eOB2]
        obstacles1 = [[275;50]]; %obstacles
        obstacles = [obstacles1];
        obstLevels = [50 25 5];
        noObst = size(obstLevels,2);
        printPath = '/Users/markusfossdal/Dropbox/SKOLE/8_SKOLE_V2018/MASTER/latex/fig/sc1';
end



%Run simulation
c1 = fix(clock); %Time and date 1
fprintf('Simulation start. Time: %d:%d:%d\n',c1(4),c1(5),c1(6));
sim('GunnerusMAN_ForceRAO.slx'); %Run simulation
fprintf('Done!\n');

%Sort analysis data
    %fm1
    data_sim = [eta_sim;nu_sim;t_sim];
    clear eta_sim nu_sim t_sim
    %fm2
    data_sim2 = [eta_sim2;nu_sim2;t_sim2];
    clear eta_sim2 nu_sim2 t_sim2
    %fm3
    data_sim3 = [eta_sim3;nu_sim3;t_sim3];
    clear eta_sim3 nu_sim3 t_sim3
    %fm4
    data_sim4 = [eta_sim4;nu_sim4;t_sim4];
    clear eta_sim4 nu_sim4 t_sim4

%Plot overview;

%whatplot:
%1) North east plot
%2) Cross-track error
%3) Failure mode plots, does not work.
%4) Risk indicator and corresponding failure mode.
%5) Consequence analysis levels
%6) Risk matrix - Fix numbers on this one.

close all
whatPlot = [1 0 0 1 1 1];
printPlot = [0 0 0 0 0 0];
OCAres = 7; %Controls number of CA plotted. Default = 1.
OCASingle = [1 3];
plotOverview;








