function [nu_dot_r,eta] = simplifiedVesselModel(tau,nu0,eta0,nu_c)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Nonlinear Unified Seakeeping and Maneuvering Model without Fluid Memory,
% based on Perez & Fossen 2007.
%
%
%MISSING: Fluid memory and Cross-Flow Drag and Surge Resistance
%
% Author: Markus Fossdal 2018.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Parameters
MRB = vessel.MRB; %Rigid-body mass matrix
MRB_inv = inv(MRB);%Rigid-body
MA = vesselABC.MA; %Added mass matrix
Bv = vessel.Bv; %Linear viscous damping matrix
Dp = vesselABC.Dp; %Linear potential damping matrix
G = vesselABC.G; % Stiffness matrix


L = [0 0 0 0 0 0; %Selection matrix
     0 0 0 0 0 1;
     0 0 0 0 -1 0;
     0 0 0 0 0 0;
     0 0 0 0 0 0; 
     0 0 0 0 0 0];


nu_r = nu-nu_c; %Relative velocity
U_r = nu_r(1,1); %Relative speed
CRB = U_r * MRB * L; % Linearized Coriolis Matrix
CA = U_r*MA*L; %Added mass matrix


%% Initial Conditions, nu & eta.
nuInit = nu0;
etaInit = eta0;


%% Computations

nu_r_dot = MRB_inv*(-(CRB+CA)*nu_r -(Bv+Dp)*nu_r -G*eta - tau);
%[J,~,~] = eulerang(eta(1,4),eta(1,5),eta(1,6));
%eta_dot = J*nu;


end