clear 
close all
clc

%Waypoint data
WP = [[100,100];[500,500];[2000,2000];[2500,3000]];

%Obstacle data
Obst = [[900,100,350];[200,500,250];[1500,2000,500];[1700,4000,200]];

%Runs function plotScenario();
plotScenario(WP,Obst);

function plotScenario(WP,Obst)
    %plotProp: Structure with plot properties
        pp.LineW = 2.0;
        pp.titleFontsize = 30;
        pp.xyLabelSize = 10;
        pp.xyTickSize = 18;
        pp.plotMarkSize = 20;
        pp.fontSize = 18;

    %Function safety
    if nargin == 0
        error('Function "plotScenario( )" is missing argument');
    end %if
    
    %Open figure and plot waypoints
        figure();
    %Initialize fullsize figure
        set(gcf, 'Position', get(0,'screensize'));
        hold on; %Figure hold function
        axis equal
        
    %Plot lines between waypoints
        plotNorthEastData(WP,pp,'-.black');
        
    %Plot Obstacles points
        plotNorthEastData(Obst,pp,'*b');
        
    %Plot obstacle text
        for i=1:size(Obst,1)
            text(Obst(i,2),Obst(i,1),sprintf('   O%d',i)...
                ,'fontsize',pp.fontSize)
        end % for
    
    %Plot obstacle circles
        for i=1:size(Obst,1)
            plotCircle(Obst(i,2),Obst(i,1),Obst(i,3),':black');
        end
        
    %Plot waypoints
        plotNorthEastData(WP,pp,'XR');
        
    %Plot Waypoint text
        for i=1:size(WP,1)
            text(WP(i,2),WP(i,1),sprintf('     WP%d',i),...
                'fontsize',pp.fontSize)
        end % for
        
        %plotFilledCircle(500,2500,500,[1 0.698 0.40],':');
        %plotFilledCircle(1000,4500,500,'none',':');
end 

function plotNorthEastData(data,pp,plotIcon,legendString)
%The following function plots two column data (x,y) coordinates in the figure created in
% "plotScenario".
    plot(data(:,2),data(:,1),plotIcon,'Linewidth',pp.LineW,'Markersize',pp.plotMarkSize)
    title('Scenario, North East','Interpreter','latex','FontSize',pp.titleFontsize);
        %Pass a third string argument in order to enable legend.
        if nargin == 4
        legend({legendString},'Interpreter','latex');
        end
    xlabel('East [m]','FontSize',pp.xyLabelSize);
    ylabel('North [m]','FontSize',pp.xyLabelSize);
    get(gca, 'XTick');
    set(gca, 'FontSize', pp.xyTickSize);
    get(gca, 'YTick');
    set(gca, 'FontSize', pp.xyTickSize);
    grid on;
end

function plotCircle(x,y,r,plotIcon)
hold on
th = 0:pi/200:2*pi;
xunit = r * cos(th) + x;
yunit = r * sin(th) + y;
plot(xunit, yunit,plotIcon);
end

function plotFilledCircle(nPos, ePos, r, fillColor, LineStyle)
r=2*r;
pos = [ePos-0.5*r,nPos-0.5*r,r,r];
rectangle('Position',pos,'Curvature',[1 1],'FaceColor',fillColor,'LineStyle',LineStyle)
end